@@ -28,6 +28,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
 
         self.on = False
         self.refresh = False
+        self.sshJustOff = 0
         
         self.start()
 
@@ -49,23 +50,17 @@ class opensshStatus(hildondesktop.StatusMenuItem):
             except:
                 subprocess.call(["rm", "/home/user/.openssh-status-widget"])
             
-        sshSystemStart = False
-        sshSystemRespawn = False
-        if path.isfile("/etc/event.d/sshd"):
-            sshFile = open("/etc/event.d/sshd",'r')
-            lines = sshFile.readlines()
-            sshFile.close()
-            for line in lines:
-                if line[0:20] == "start on stopped rcS":
-                    sshSystemStart = True
-                if line[0:7] == "respawn":
-                    sshSystemRespawn = True
-        if sshSystemRespawn and not skipSystemCheck:
-            self.adjustSshFile()
-        
-        if sshSystemStart and self.stopTracking:
-            self.count = 0
-            gobject.timeout_add(10000, self.sshRestartTracker)
+        if not skipSystemCheck:
+            sshSystemRespawn = False
+            if path.isfile("/etc/event.d/sshd"):
+                sshFile = open("/etc/event.d/sshd",'r')
+                lines = sshFile.readlines()
+                sshFile.close()
+                for line in lines:
+                    if line.strip('\n').strip(' ') == "respawn":
+                        sshSystemRespawn = True
+            if sshSystemRespawn:
+                self.adjustSshFile()
         
         self.sshStatus()
         if self.sshRunning:
@@ -88,16 +83,6 @@ class opensshStatus(hildondesktop.StatusMenuItem):
                     self.refresh = True
                     gobject.timeout_add(2000, self.sshTracker)
             
-    def sshRestartTracker(self):
-        self.count +=1
-        if not self.refresh:
-            self.refresh = True
-            gobject.timeout_add(2000, self.sshTracker)
-        if self.count < 4:
-            return True
-        else:
-            return False
-        
     def adjustSshFile(self):
         self.dialog = gtk.Dialog("OpenSSH status", None)
         text = gtk.Label("The widget has detected a system configuration for respawning the OpenSSH server. "
@@ -158,6 +143,8 @@ class opensshStatus(hildondesktop.StatusMenuItem):
     def sshTracker(self):
         self.sshStatus()
         self.sshUsers()
+        if self.sshRunning and self.sshJustOff:
+            self.sshJustOff = 0
         if not self.sshRunning and self.on:
             self.on = False
             self.button.set_image(self.image_off)
@@ -172,15 +159,20 @@ class opensshStatus(hildondesktop.StatusMenuItem):
             self.button.set_text("OpenSSH Server", str(self.sshConnected)+" connections")
             return True
         else:
-            self.on = False
-            self.button.set_image(self.image_off)
-            self.set_status_area_icon()
-            self.button.set_text("OpenSSH Server", "Off")
-            if self.stopTracking:
-                self.refresh = False
-                return False
-            else:
+            if self.sshJustOff < 1:
+                self.sshJustOff += 1
                 return True
+            else:
+                self.sshJustOff = 0
+                self.on = False
+                self.button.set_image(self.image_off)
+                self.set_status_area_icon()
+                self.button.set_text("OpenSSH Server", "Off")
+                if self.stopTracking:
+                    self.refresh = False
+                    return False
+                else:
+                    return True
         
     def buttonClicked(self, dummy):
         self.sshStatus()
@@ -209,7 +201,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
             if not self.refresh:
                 self.refresh = True
                 gobject.timeout_add(2000, self.sshTracker)
-            self.printDialog("OpenSSH Server already running! Display corrected.")
+            self.printDialog("OpenSSH Server already running! Display updated.")
         else:
             self.sshUsers()
             subprocess.call(["sudo", "/usr/sbin/openssh-status.sh", "start_sshd"])
